@@ -49,7 +49,14 @@ class TransformerBuilder(nn.Module):
             sys.modules["optimizers"] = s3prl.optimizers
 
             self.all_states = torch.load(options["ckpt_file"], map_location='cpu')
-            self.config = self.all_states['Config']
+            if 'transformer' in self.all_states['Config']:
+                # for legacy ckpts, 'Config' stored the upstream config, and runner config was stored under 'Runner'.
+                self.config = self.all_states['Config']
+            elif 'transformer' in self.all_states['Upstream_Config']:
+                # For new ckpts, 'Upstream_Config' is used to store the upstream config, and runner config is now stored under 'Config'.
+                self.config = self.all_states['Upstream_Config']
+            else:
+                raise NotImplementedError
 
             del sys.modules["optimizers"]
             if original_optimizer is not None:
@@ -78,7 +85,7 @@ class TransformerBuilder(nn.Module):
             self.config['audio'] = yaml.load(open(on_the_fly_config, 'r'), Loader=yaml.FullLoader)
         if 'audio' in self.config:
             if 'kaldi' in self.config['audio']:
-                self.extracter, self.inp_dim = get_extracter(self.config['audio'])
+                self.extracter, self.inp_dim, _ = get_extracter(self.config['audio'])
                 self.spec_dim = self.inp_dim
             else:
                 self.extracter, self.inp_dim, self.spec_dim = get_preprocessor(self.config['audio'], process_input_only=True)
@@ -282,9 +289,10 @@ class PretrainedTransformer(TransformerBuilder):
                 x = pad_sequence(x, batch_first=True)
             else:
                 x = [self._normalize_wav_decibel(x_i) for x_i in x]
+                x_lens = [len(x_) for x_ in x]
                 x = pad_sequence(x, batch_first=True)
                 x = x.unsqueeze(1) # (batch_size, audio_len) -> (batch_size, 1, audio_len)
-                x = self.extracter(x)[0]
+                x = self.extracter(x, wavs_len=x_lens)[0]
         if self.no_grad:
             with torch.no_grad():
                 x = self._forward(x)
@@ -316,9 +324,10 @@ class PretrainedTransformerWithHead(PretrainedTransformer):
                 x = pad_sequence(x, batch_first=True)
             else:
                 x = [self._normalize_wav_decibel(x_i) for x_i in x]
+                x_lens = [len(x_) for x_ in x]
                 x = pad_sequence(x, batch_first=True)
                 x = x.unsqueeze(1) # (batch_size, audio_len) -> (batch_size, 1, audio_len)
-                x = self.extracter(x)[0]
+                x = self.extracter(x, wavs_len=x_lens)[0]
         if self.no_grad:
             with torch.no_grad():
                 x = self._forward(x)
@@ -430,4 +439,4 @@ class LIN(nn.Module):
         
     def forward(self, x):
         x = self.linear(x)
-        return x
\ No newline at end of file
+        return x
